==> vlc-debug-1:3.0.22-3-x86_64.pkg.tar.zst: usr/src/debug/vlc/vlc-a89e30a4d2cb156b8a4f68aa52b11ebd0d8eb25a/modules/gui/qt/widgets_qmlassets.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x3,0x99,
  0x28,
  0xb5,0x2f,0xfd,0x60,0xda,0xb,0x7d,0x1c,0x0,0x16,0xe1,0x5b,0x1d,0x40,0x75,0xe,
  0x3f,0x66,0xe7,0xa9,0x24,0xd9,0x48,0xee,0x91,0x76,0xc3,0xfb,0x9b,0x99,0xb,0x77,
  0xfb,0x8e,0xe0,0x15,0x18,0x8a,0x8a,0x46,0x4,0x2e,0x58,0x0,0x53,0x0,0x51,0x0,
  0x4d,0x59,0xfd,0x58,0xe5,0x26,0xa2,0xe5,0x86,0xa5,0x86,0x5b,0xff,0x42,0xc9,0xfb,
  0x91,0x69,0xe3,0x6,0xc8,0xbd,0xe4,0x96,0x28,0xb4,0x78,0x32,0x63,0xe4,0x68,0xa9,
  0x4f,0x40,0xb8,0x9e,0x1d,0x9,0xf7,0xff,0x8b,0xb8,0xf5,0xd9,0x1,0xb0,0x16,0x47,
  0x10,0x20,0x8,0xa,0x81,0xff,0x24,0x36,0x29,0x7c,0x0,0x6,0x3,0xe9,0x71,0x19,
  0xac,0xc5,0x19,0x3c,0x67,0x60,0x8,0x78,0x66,0xd2,0x2f,0x80,0xfb,0xac,0x9a,0x62,
  0x4,0xd2,0xe3,0x12,0xc8,0x7d,0xad,0xad,0x59,0x59,0x7c,0xee,0x90,0x7a,0x33,0x9e,
  0x95,0x1,0xfa,0xcb,0xf2,0xa4,0x5e,0x9a,0xfa,0xa2,0x31,0x5e,0x9f,0x44,0x7a,0xac,
  0xfc,0x46,0xf5,0x9c,0xee,0xf,0xf3,0xa7,0x74,0xaf,0x21,0x9e,0xdb,0x18,0x19,0x17,
  0x3a,0x22,0x72,0xa1,0xc5,0x91,0xca,0x7d,0xf5,0x74,0x63,0xc5,0xe4,0x94,0x56,0x6a,
  0x2c,0x88,0xa9,0xe5,0xa3,0xa5,0xcc,0x34,0xa3,0xdf,0x91,0x8a,0xf5,0xb1,0x57,0xd1,
  0xf8,0xb5,0x57,0x1b,0x86,0x11,0xd3,0x5,0xf9,0xa7,0xa3,0x7a,0xf9,0x73,0x4b,0xef,
  0xdd,0x74,0x3f,0x1d,0x69,0x98,0x63,0x6e,0x3b,0x9b,0xfa,0xdf,0xe1,0x3f,0xe9,0x5c,
  0x7a,0xd5,0x2d,0x1b,0xbf,0xae,0x80,0x70,0x27,0xdb,0x52,0x2e,0x85,0x95,0x76,0x30,
  0xf2,0x78,0x9c,0xfb,0xfa,0xd4,0x9b,0xb2,0xd3,0x12,0x6a,0x4b,0x88,0xe3,0x22,0x6b,
  0x4f,0x37,0xd4,0x4c,0xbf,0xf,0x33,0xe9,0xd9,0x30,0x19,0x5d,0xc9,0xa5,0xd0,0xf2,
  0x4e,0x1f,0x59,0xa1,0x85,0xbe,0xdd,0x16,0xd6,0xc8,0x90,0xba,0x80,0xb5,0x38,0x82,
  0xb7,0x51,0x3a,0xf4,0xa0,0x63,0xf1,0xf1,0xa4,0xcd,0xed,0x5d,0x31,0x3e,0xcb,0x4a,
  0xcb,0xd6,0x86,0x8d,0x73,0xa3,0x77,0x8b,0xfa,0x7e,0xbd,0xcb,0x5b,0xd1,0x12,0x15,
  0x6b,0xc3,0x5c,0xea,0xf5,0xd5,0x97,0x5a,0x9e,0x65,0x26,0x93,0x70,0xe,0x77,0xd1,
  0xf2,0x5d,0xfb,0xa5,0x5f,0xb1,0x3e,0x6b,0xeb,0xe2,0xa3,0x74,0x36,0xbd,0x80,0xb0,
  0x6d,0xaa,0xc2,0xb1,0xf5,0x1a,0xf6,0x63,0xc3,0xf0,0x39,0x81,0x23,0xa8,0xc1,0xca,
  0x8,0x8d,0x8c,0x94,0x14,0x24,0x95,0xc6,0x21,0xc,0x1,0x42,0x35,0xa9,0xae,0x3c,
  0x31,0x8,0x88,0x52,0x8e,0x29,0x86,0x66,0x4c,0x94,0xc,0x73,0x26,0x0,0x0,0x56,
  0x7a,0x60,0xc8,0xe5,0x2c,0x3,0xdc,0xb8,0x94,0xd0,0x69,0xea,0x1a,0xaf,0x5d,0xca,
  0xc0,0xb1,0x90,0xa3,0x9c,0xb0,0x89,0xf0,0x12,0x12,0xc,0xcd,0x70,0xa0,0xf7,0x4d,
  0x87,0x22,0xcb,0xdc,0xaa,0x86,0xbc,0x66,0x3d,0x14,0xef,0xcf,0x70,0x48,0x4c,0x78,
  0xc1,0xe8,0xd,0xe6,0xf3,0x5d,0xa9,0x62,0xc1,0xbe,0xcb,0xc3,0x32,0x65,0x81,0x99,
  0x64,0x22,0xde,0x82,0x59,0x3b,0xd7,0x76,0x81,0x28,0x1a,0x1,0xc9,0x64,0xdc,0xb4,
  0x69,0x45,0x49,0x8b,0x74,0x16,0xfa,0x4d,0x80,0x19,0x99,0x27,0xcb,0xe4,0x72,0x9a,
  0xae,0xf5,0x3d,0x7a,0xa9,0x74,0x1d,0xde,0x46,0xa4,0x6f,0xae,0x66,0x97,0x46,0xaa,
  0xef,0x59,0x29,0xe8,0xb0,0x93,0xb7,0x59,0xea,0x25,0x9,0xea,0x2a,0x4b,0xcc,0xa,
  0x6d,0xbf,0xc4,0xab,0xc6,0x11,0x59,0x4b,0x9a,0xb5,0x8d,0x2f,0xd6,0x84,0x30,0x5,
  0x28,0x14,0x5,0x45,0x46,0x46,0x25,0x1c,0x55,0x99,0xed,0xd8,0x34,0x90,0x11,0x39,
  0xa2,0x11,0xf7,0xfe,0x7,0xe3,0x9f,0x49,0x8,0x9f,0x54,0x2,0xca,0xbc,0xbd,0xf8,
  0xd4,0x23,0xf9,0xb8,0x71,0x6,0x59,0x20,0x1c,0x7c,0xb7,0x1,0x8f,0x26,0x90,0xe1,
  0x69,0x2d,0xab,0xc2,0x2f,0xd2,0xcf,0x11,0x81,0xb1,0x5c,0xd1,0xa0,0xb4,0x60,0xce,
  0xa7,0x5f,0x3a,0xdd,0x95,0x66,0x48,0xce,0xc2,0xa0,0x47,0x19,0x1c,0x69,0xe3,0x82,
  0x46,0x38,0xf8,0xd9,0x76,0x39,0xa7,0xf5,0x90,0x8f,0x44,0x81,0x89,0x1f,0xb,0x92,
  0x35,0xa4,0x9a,0x2e,0x8f,0xf4,0xc4,0x78,0x61,0x21,0xc6,0xae,0xd4,0xd7,0xaf,0x5,
  0x2a,0x92,0x3,0xcc,0x5e,0x62,0x8,0x6b,0xea,0xa,0x47,0xc9,0x72,0x42,0x3d,0x5c,
  0xb2,0x4,0x11,0xd,0x35,0xc7,0xc2,0xb1,0x44,0xb6,0xfd,0x74,0x14,0x4a,0xcd,0xd6,
  0xfb,0xb5,0x70,0x43,0xbe,0x52,0x2d,0x7e,0xc1,0x4c,0x6b,0x70,0xc7,0xd2,0x2f,0xad,
  0x10,0x5e,0x1a,0xf7,0xd,0x78,0x19,0x88,0x6e,0x44,0xe,0xd9,0xd4,0xc6,0xcd,0x3,
  0xbf,0xe8,0xec,0xb1,0x18,0x52,0x59,0xf7,0xe5,0x71,0xdb,0xd1,0x84,0x19,0xf6,0x82,
  0xc,0xab,0x24,0xe7,0xc0,0xf7,0x82,0xd5,0x58,0x8e,0x19,0x96,0xab,0xc5,0xc6,0x6,
  0x57,0x47,0x90,0x8e,0x88,0xa0,0x4a,0xa3,0xed,0xaf,0x7d,0x3b,0x8a,0x6e,0x49,0x65,
  0x58,0xa4,0xe2,0xb3,0x6d,0xa3,0x54,0xbc,0x9,0x3f,0xa6,0xa5,0xb1,0xd,0x82,0x74,
  0xef,0x86,0x4b,0x38,0xaa,0x9a,0x80,0x76,0xe5,0xe2,0x52,0xb4,0xf,0x17,0x8b,0x72,
  0x3f,0xaa,0x85,0x9d,0x27,0x58,0x86,0x0,0x4f,0x5c,0x56,0xee,0x5b,0xa8,0x55,0x22,
  0xcc,0xb7,0xe2,0x3d,0x1,0x2d,0xeb,0x75,0xf9,0x16,0xdb,0xdc,0x34,0x65,0x5,0x4e,
  0xff,0x7d,0xa5,0x2a,0x51,0x2b,0x7a,0x43,0xdc,0x7c,0xf,0xf4,0x48,0xe0,0xf7,0xd5,
  0x52,0x8f,0xed,0xdb,0x32,0xcf,0x2e,0xab,0xaf,0x3e,0xf8,0x2a,0x31,0x8d,0x63,0xd2,
  0x2c,0x2,0xa,0x97,0x78,0x92,0xc5,0x73,0xda,0x16,0xb0,0x7a,0x5d,0x9e,0x90,0xe4,
  0x3e,0x13,0x5f,0xf6,0xe5,0x77,0x9d,0x6b,0x7,0x34,0x60,0xac,0x69,0x36,0x59,0x29,
  0x80,0x5c,0x85,0x26,0xfd,0xcb,0x59,0x15,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // VLC
  0x0,0x3,
  0x0,0x0,0x5b,0x3,
  0x0,0x56,
  0x0,0x4c,0x0,0x43,
    // Widgets
  0x0,0x7,
  0xd,0xfa,0xdc,0x13,
  0x0,0x57,
  0x0,0x69,0x0,0x64,0x0,0x67,0x0,0x65,0x0,0x74,0x0,0x73,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x99,0xbe,0xdf,0x82,0x58,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x99,0xbe,0xdf,0x82,0x58,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x99,0xbe,0xdf,0x82,0x58,
  // :/qt/qml/VLC
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x99,0xbe,0xdf,0x82,0x58,
  // :/qt/qml/VLC/Widgets
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x99,0xbe,0xdf,0x82,0x58,
  // :/qt/qml/VLC/Widgets/qmldir
  0x0,0x0,0x0,0x36,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x99,0xbe,0xdf,0x82,0x58,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_widgets_assets)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_widgets_assets)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_widgets_assets)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_widgets_assets)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_widgets_assets)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_widgets_assets)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> vlc-debug-1:3.0.22-4-x86_64.pkg.tar.zst: usr/src/debug/vlc/vlc-a89e30a4d2cb156b8a4f68aa52b11ebd0d8eb25a/modules/gui/qt/widgets_qmlassets.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x3,0x99,
  0x28,
  0xb5,0x2f,0xfd,0x60,0xda,0xb,0x7d,0x1c,0x0,0x16,0xe1,0x5b,0x1d,0x40,0x75,0xe,
  0x3f,0x66,0xe7,0xa9,0x24,0xd9,0x48,0xee,0x91,0x76,0xc3,0xfb,0x9b,0x99,0xb,0x77,
  0xfb,0x8e,0xe0,0x15,0x18,0x8a,0x8a,0x46,0x4,0x2e,0x58,0x0,0x53,0x0,0x51,0x0,
  0x4d,0x59,0xfd,0x58,0xe5,0x26,0xa2,0xe5,0x86,0xa5,0x86,0x5b,0xff,0x42,0xc9,0xfb,
  0x91,0x69,0xe3,0x6,0xc8,0xbd,0xe4,0x96,0x28,0xb4,0x78,0x32,0x63,0xe4,0x68,0xa9,
  0x4f,0x40,0xb8,0x9e,0x1d,0x9,0xf7,0xff,0x8b,0xb8,0xf5,0xd9,0x1,0xb0,0x16,0x47,
  0x10,0x20,0x8,0xa,0x81,0xff,0x24,0x36,0x29,0x7c,0x0,0x6,0x3,0xe9,0x71,0x19,
  0xac,0xc5,0x19,0x3c,0x67,0x60,0x8,0x78,0x66,0xd2,0x2f,0x80,0xfb,0xac,0x9a,0x62,
  0x4,0xd2,0xe3,0x12,0xc8,0x7d,0xad,0xad,0x59,0x59,0x7c,0xee,0x90,0x7a,0x33,0x9e,
  0x95,0x1,0xfa,0xcb,0xf2,0xa4,0x5e,0x9a,0xfa,0xa2,0x31,0x5e,0x9f,0x44,0x7a,0xac,
  0xfc,0x46,0xf5,0x9c,0xee,0xf,0xf3,0xa7,0x74,0xaf,0x21,0x9e,0xdb,0x18,0x19,0x17,
  0x3a,0x22,0x72,0xa1,0xc5,0x91,0xca,0x7d,0xf5,0x74,0x63,0xc5,0xe4,0x94,0x56,0x6a,
  0x2c,0x88,0xa9,0xe5,0xa3,0xa5,0xcc,0x34,0xa3,0xdf,0x91,0x8a,0xf5,0xb1,0x57,0xd1,
  0xf8,0xb5,0x57,0x1b,0x86,0x11,0xd3,0x5,0xf9,0xa7,0xa3,0x7a,0xf9,0x73,0x4b,0xef,
  0xdd,0x74,0x3f,0x1d,0x69,0x98,0x63,0x6e,0x3b,0x9b,0xfa,0xdf,0xe1,0x3f,0xe9,0x5c,
  0x7a,0xd5,0x2d,0x1b,0xbf,0xae,0x80,0x70,0x27,0xdb,0x52,0x2e,0x85,0x95,0x76,0x30,
  0xf2,0x78,0x9c,0xfb,0xfa,0xd4,0x9b,0xb2,0xd3,0x12,0x6a,0x4b,0x88,0xe3,0x22,0x6b,
  0x4f,0x37,0xd4,0x4c,0xbf,0xf,0x33,0xe9,0xd9,0x30,0x19,0x5d,0xc9,0xa5,0xd0,0xf2,
  0x4e,0x1f,0x59,0xa1,0x85,0xbe,0xdd,0x16,0xd6,0xc8,0x90,0xba,0x80,0xb5,0x38,0x82,
  0xb7,0x51,0x3a,0xf4,0xa0,0x63,0xf1,0xf1,0xa4,0xcd,0xed,0x5d,0x31,0x3e,0xcb,0x4a,
  0xcb,0xd6,0x86,0x8d,0x73,0xa3,0x77,0x8b,0xfa,0x7e,0xbd,0xcb,0x5b,0xd1,0x12,0x15,
  0x6b,0xc3,0x5c,0xea,0xf5,0xd5,0x97,0x5a,0x9e,0x65,0x26,0x93,0x70,0xe,0x77,0xd1,
  0xf2,0x5d,0xfb,0xa5,0x5f,0xb1,0x3e,0x6b,0xeb,0xe2,0xa3,0x74,0x36,0xbd,0x80,0xb0,
  0x6d,0xaa,0xc2,0xb1,0xf5,0x1a,0xf6,0x63,0xc3,0xf0,0x39,0x81,0x23,0xa8,0xc1,0xca,
  0x8,0x8d,0x8c,0x94,0x14,0x24,0x95,0xc6,0x21,0xc,0x1,0x42,0x35,0xa9,0xae,0x3c,
  0x31,0x8,0x88,0x52,0x8e,0x29,0x86,0x66,0x4c,0x94,0xc,0x73,0x26,0x0,0x0,0x56,
  0x7a,0x60,0xc8,0xe5,0x2c,0x3,0xdc,0xb8,0x94,0xd0,0x69,0xea,0x1a,0xaf,0x5d,0xca,
  0xc0,0xb1,0x90,0xa3,0x9c,0xb0,0x89,0xf0,0x12,0x12,0xc,0xcd,0x70,0xa0,0xf7,0x4d,
  0x87,0x22,0xcb,0xdc,0xaa,0x86,0xbc,0x66,0x3d,0x14,0xef,0xcf,0x70,0x48,0x4c,0x78,
  0xc1,0xe8,0xd,0xe6,0xf3,0x5d,0xa9,0x62,0xc1,0xbe,0xcb,0xc3,0x32,0x65,0x81,0x99,
  0x64,0x22,0xde,0x82,0x59,0x3b,0xd7,0x76,0x81,0x28,0x1a,0x1,0xc9,0x64,0xdc,0xb4,
  0x69,0x45,0x49,0x8b,0x74,0x16,0xfa,0x4d,0x80,0x19,0x99,0x27,0xcb,0xe4,0x72,0x9a,
  0xae,0xf5,0x3d,0x7a,0xa9,0x74,0x1d,0xde,0x46,0xa4,0x6f,0xae,0x66,0x97,0x46,0xaa,
  0xef,0x59,0x29,0xe8,0xb0,0x93,0xb7,0x59,0xea,0x25,0x9,0xea,0x2a,0x4b,0xcc,0xa,
  0x6d,0xbf,0xc4,0xab,0xc6,0x11,0x59,0x4b,0x9a,0xb5,0x8d,0x2f,0xd6,0x84,0x30,0x5,
  0x28,0x14,0x5,0x45,0x46,0x46,0x25,0x1c,0x55,0x99,0xed,0xd8,0x34,0x90,0x11,0x39,
  0xa2,0x11,0xf7,0xfe,0x7,0xe3,0x9f,0x49,0x8,0x9f,0x54,0x2,0xca,0xbc,0xbd,0xf8,
  0xd4,0x23,0xf9,0xb8,0x71,0x6,0x59,0x20,0x1c,0x7c,0xb7,0x1,0x8f,0x26,0x90,0xe1,
  0x69,0x2d,0xab,0xc2,0x2f,0xd2,0xcf,0x11,0x81,0xb1,0x5c,0xd1,0xa0,0xb4,0x60,0xce,
  0xa7,0x5f,0x3a,0xdd,0x95,0x66,0x48,0xce,0xc2,0xa0,0x47,0x19,0x1c,0x69,0xe3,0x82,
  0x46,0x38,0xf8,0xd9,0x76,0x39,0xa7,0xf5,0x90,0x8f,0x44,0x81,0x89,0x1f,0xb,0x92,
  0x35,0xa4,0x9a,0x2e,0x8f,0xf4,0xc4,0x78,0x61,0x21,0xc6,0xae,0xd4,0xd7,0xaf,0x5,
  0x2a,0x92,0x3,0xcc,0x5e,0x62,0x8,0x6b,0xea,0xa,0x47,0xc9,0x72,0x42,0x3d,0x5c,
  0xb2,0x4,0x11,0xd,0x35,0xc7,0xc2,0xb1,0x44,0xb6,0xfd,0x74,0x14,0x4a,0xcd,0xd6,
  0xfb,0xb5,0x70,0x43,0xbe,0x52,0x2d,0x7e,0xc1,0x4c,0x6b,0x70,0xc7,0xd2,0x2f,0xad,
  0x10,0x5e,0x1a,0xf7,0xd,0x78,0x19,0x88,0x6e,0x44,0xe,0xd9,0xd4,0xc6,0xcd,0x3,
  0xbf,0xe8,0xec,0xb1,0x18,0x52,0x59,0xf7,0xe5,0x71,0xdb,0xd1,0x84,0x19,0xf6,0x82,
  0xc,0xab,0x24,0xe7,0xc0,0xf7,0x82,0xd5,0x58,0x8e,0x19,0x96,0xab,0xc5,0xc6,0x6,
  0x57,0x47,0x90,0x8e,0x88,0xa0,0x4a,0xa3,0xed,0xaf,0x7d,0x3b,0x8a,0x6e,0x49,0x65,
  0x58,0xa4,0xe2,0xb3,0x6d,0xa3,0x54,0xbc,0x9,0x3f,0xa6,0xa5,0xb1,0xd,0x82,0x74,
  0xef,0x86,0x4b,0x38,0xaa,0x9a,0x80,0x76,0xe5,0xe2,0x52,0xb4,0xf,0x17,0x8b,0x72,
  0x3f,0xaa,0x85,0x9d,0x27,0x58,0x86,0x0,0x4f,0x5c,0x56,0xee,0x5b,0xa8,0x55,0x22,
  0xcc,0xb7,0xe2,0x3d,0x1,0x2d,0xeb,0x75,0xf9,0x16,0xdb,0xdc,0x34,0x65,0x5,0x4e,
  0xff,0x7d,0xa5,0x2a,0x51,0x2b,0x7a,0x43,0xdc,0x7c,0xf,0xf4,0x48,0xe0,0xf7,0xd5,
  0x52,0x8f,0xed,0xdb,0x32,0xcf,0x2e,0xab,0xaf,0x3e,0xf8,0x2a,0x31,0x8d,0x63,0xd2,
  0x2c,0x2,0xa,0x97,0x78,0x92,0xc5,0x73,0xda,0x16,0xb0,0x7a,0x5d,0x9e,0x90,0xe4,
  0x3e,0x13,0x5f,0xf6,0xe5,0x77,0x9d,0x6b,0x7,0x34,0x60,0xac,0x69,0x36,0x59,0x29,
  0x80,0x5c,0x85,0x26,0xfd,0xcb,0x59,0x15,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // VLC
  0x0,0x3,
  0x0,0x0,0x5b,0x3,
  0x0,0x56,
  0x0,0x4c,0x0,0x43,
    // Widgets
  0x0,0x7,
  0xd,0xfa,0xdc,0x13,
  0x0,0x57,
  0x0,0x69,0x0,0x64,0x0,0x67,0x0,0x65,0x0,0x74,0x0,0x73,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x99,0xee,0x10,0x42,0x38,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x99,0xee,0x10,0x42,0x38,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x99,0xee,0x10,0x42,0x38,
  // :/qt/qml/VLC
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x99,0xee,0x10,0x42,0x38,
  // :/qt/qml/VLC/Widgets
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x99,0xee,0x10,0x42,0x38,
  // :/qt/qml/VLC/Widgets/qmldir
  0x0,0x0,0x0,0x36,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x99,0xee,0x10,0x42,0x38,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_widgets_assets)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_widgets_assets)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_widgets_assets)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_widgets_assets)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_widgets_assets)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_widgets_assets)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
